# Maestro

[![Documentation Status](https://readthedocs.org/projects/maestro-lps/badge/?version=latest)](https://maestro-lps.readthedocs.io/en/latest/?badge=latest)
[![Build Status](https://travis-ci.org/gabriel-milan/maestro.svg?branch=master)](https://travis-ci.org/gabriel-milan/maestro)
[![PyPI Version](https://img.shields.io/pypi/v/lps-maestro)](https://pypi.org/project/lps-maestro/)
[![Python Versions](https://img.shields.io/pypi/pyversions/lps-maestro)](https://github.com/gabriel-milan/maestro)
[![Vulnerabilities](https://img.shields.io/snyk/vulnerabilities/github/gabriel-milan/maestro)](https://github.com/gabriel-milan/maestro)
[![License](https://img.shields.io/github/license/gabriel-milan/maestro)](https://github.com/gabriel-milan/maestro)

## Getting started

* Clone this repository
```
git clone https://github.com/gabriel-milan/maestro
```

* Go to the cloned directory:
```
cd maestro/
```

* Run the setup script
```
source setup.sh
```

* Install dependencies
```
pip3 install -r requirements.txt
```

* Run it!
```
maestro --help
```
